@@ -65,9 +65,9 @@ if ($gIn['a'] == 'L') { // ꗗ[h̏ꍇ
 
   // ͂0oCgȂAt@C폜B
   // gbv͏ꂽ炦炢ƂɂȂ̂ŋ֎~B
-  if ((strlen($gIn['body']) == '0') && ($gIn['title'] != 'gbv')) {
+  if ((strlen($gIn['body']) == '0') && (decode($gIn['title']) != $MOWIKI_FRONTPAGE)) {
 	
-	$filename = $MOWIKI_DATA.encode($gIn['title']).'.txt';
+	$filename = $MOWIKI_DATA.$gIn['title'].'.txt';
 	
 	if (file_exists($filename)) {
 	  unlink($filename);
@@ -111,7 +111,7 @@ if ($gIn['a'] == 'L') { // ꗗ[h̏ꍇ
   
 } else { // wy[W\[h̏ꍇ
   if (strlen($gIn['title']) == '0') {
-	$gIn['title'] = 'gbv';
+	$gIn['title'] = encode($MOWIKI_FRONTPAGE);
   }
   
   // y[W\
