@@ -38,7 +38,7 @@ if (count($gDef['page_names']) > '0') {
 
 
 	// ꗗ\쐬
-	$gOut['body'] .= '<a href="'.$_SERVER['PHP_SELF'].'?a=V&title='.decode($key).'">'
+	$gOut['body'] .= '<a href="'.$_SERVER['PHP_SELF'].'?a=V&title='.$key.'">'
 	  .decode($key).'</a> '.$mean.'<br>'."\n";
 
 	$i++;
