@@ -1,6 +1,16 @@
 <?php
 // t@C쐬
-$filename = $MOWIKI_DATA.encode($gIn['title']).'.txt';
+if (preg_match("/^%/", $gIn['title'])) {
+  $gIn['title'] = encode(rawurldecode($gIn['title']));
+} else if (mb_detect_encoding($gIn['title']) == 'ASCII') {
+  $gIn['title'] = $gIn['title'];
+} else {
+  if (mb_detect_encoding($gIn['title']) != 'SJIS') {
+	$gIn['title'] = mb_convert_encoding($gIn['title'], 'SJIS');
+  }
+  $gIn['title'] = encode($gIn['title']);
+}
+$filename = $MOWIKI_DATA.$gIn['title'].'.txt';
 
 // t@C̑݃`FbN
 if (file_exists($filename)) {
@@ -14,7 +24,7 @@ if (file_exists($filename)) {
 
 // y[WҏWʂ\
 $gOut['body'] = '<form method=POST action='.$_SERVER['PHP_SELF'].'>'
-. $gIn['title'].'<br>'
+. decode($gIn['title']).'<br>'
 .'<input name="ts" type="hidden" value="'.time().'">'
 .'<input name="title" type="hidden" value="'.$gIn['title'].'">'
 . '<textarea name="body" cols="20" rows="5">'.$contents.'</textarea><br>'
