@@ -3,12 +3,19 @@
 ?>
 <?php
 // t@C쐬
-$filename = $MOWIKI_DATA.encode($gIn['title']).'.txt';
+$filename = $MOWIKI_DATA.$gIn['title'].'.txt';
 
 // t@C̑݃`FbN
 if (!file_exists($filename)) {
-  // VK[h
-  require($MOWIKI_LIB.'newpage.php');
+  if (decode($gIn['title']) == $MOWIKI_FRONTPAGE) {
+	// gbv̏ꍇ́AҏWɓȂ
+	$gOut['body'] = '<i><b>'.decode($gIn['title'])."</b></i>";
+	$gOut['edit'] = 1;
+  } else {
+	// VK[h
+	require($MOWIKI_LIB.'newpage.php');
+  }
+  
   require($MOWIKI_VIEW.'template.php');
   exit;
 }
@@ -55,12 +62,30 @@ while (strlen($contents[$i]) > 0) {
 	$contents[$i] = preg_replace("/^$MOWIKI_LI0/", '<li>', $contents[$i]);
   }
 
+  // <hr>
+  if (preg_match("/^$MOWIKI_HR(\r\n|\n)/", $contents[$i])) {
+	$contents[$i] = '<hr color="'.$MOWIKI_HR_COLOR.'">';
+  }
+
+  $i++;
+}
+
+// ϊς݂̃y[We
+$i = 0;
+while (strlen($contents[$i]) > 0) {
+  if (preg_match('/^<li>/', $contents[($i - 1)])) {
+	$tmp .= "\n".$contents[$i];
+  } else if (preg_match("/^<hr.+>/", $contents[($i - 1)])) {
+	$tmp .= "\n".$contents[$i];
+  } else {
+	$tmp .= "<br>\n".$contents[$i];
+  }
   $i++;
 }
 
 // $contents = ereg_replace("\n", "<br>\n", $contents);
 
 // \pϐ
-$tmp = implode('<br>', $contents);
-$gOut['body'] = '<i><b>'.$gIn['title']."</b></i><br>\n".$tmp;
+// $tmp = implode('<br>', $contents);
+$gOut['body'] = '<i><b>'.decode($gIn['title'])."</b></i><br>\n".$tmp;
 ?>
\ No newline at end of file
