@@ -1,6 +1,6 @@
 <?php
 // t@CXVEۑ
-$filename = $MOWIKI_DATA.encode($gIn['title']).'.txt';
+$filename = $MOWIKI_DATA.$gIn['title'].'.txt';
 
 // XV`FbN
 if (file_exists($filename)) {
