@@ -8,17 +8,23 @@ $MOWIKI_VIEW = 'view/';
 $MOWIKI_TITLE = 'MoWiKi';
 $MOWIKI_ADMIN = 'Randolph';
 
+// gbvy[W̖O
+$MOWIKI_FRONTPAGE = 'gbv';
+
 // \F̐ݒ
 $MOWIKI_BG = '#AAAAFF';
 $MOWIKI_TEXT = '#000000';
 $MOWIKI_LINK = '#0000FF';
 $MOWIKI_ALINK = '#006666';
 $MOWIKI_VLINK = '#006666';
-$MOWIKI_HR = '#000000';
+$MOWIKI_HR_COLOR = '#000000';
+
+// HR
+// sɂꂾĂƁA<hr>ɕϊB
+$MOWIKI_HR = '';
 
 // ӏ̃^OݒB
 //  Ƃƌgтœ͂₷ȂłB
-
 $MOWIKI_LI0 = ' ';
 $MOWIKI_LI1 = ' ';
 $MOWIKI_LI2 = ' ';
