@@ -8,11 +8,11 @@
 <?php } ?>
 <a href="<?php print $_SERVER['PHP_SELF']?>?r=<?php print $MOWIKI_RAND?>" accesskey="2">gbv</a> 
 <a href="<?php print $_SERVER['PHP_SELF']?>?a=L&r=<?php print $MOWIKI_RAND?>" accesskey="3">Xg</a> 
-<hr color="<?php print $MOWIKI_HR?>">
+<hr color="<?php print $MOWIKI_HR_COLOR?>">
 <?php print $gOut['body']?>
-<hr color="<?php print $MOWIKI_HR?>">
+<hr color="<?php print $MOWIKI_HR_COLOR?>">
 <?php if ($gOut['edit'] == 1) { ?>
-<a href="<?php print $_SERVER['PHP_SELF']?>?a=M&title=<?php print encode($gIn['title'])?>" accesskey="0">̃y[WҏW</a><br>
+<a href="<?php print $_SERVER['PHP_SELF']?>?a=M&title=<?php print $gIn['title']?>" accesskey="0">̃y[WҏW</a><br>
 <?php } ?>
 <br>
 Admin: <?php print $MOWIKI_ADMIN?><br>
